%% Formation analyse de series organisee par Ingrid Puillat et Dhouha Kbaier
% Lieu: Ifremer, Brest, France
% Dates: Mercredi 27 et Jeudi 28 Mai 2015 (Session1); puis Mercredi 3 et Jeudi 4 Juin 2015 (Session 2)
% Auteur: Dhouha Kbaier Ben Ismail
% e-mail: dhouha.kbaier@ifremer.fr

%%
close all;
clear all;
global time_data;
global series_data;
global interval;
global xLabel;
global yLabel;
global titre;

%% Telecharger vos donnes ici
% load Seattle_tide; %http://courses.washington.edu/ocean421/resources.shtml
% time_data=date;
% series_data=zeta;
% interval=0.1;

% load maree_conquet;
% interval=1/60; % toutes les minutes
% time_data=(date2(1): 1/(60*24):date2(end))';
% interpolation=interp1(date2,xe,time_data) ;
% series_data=interpolation-nanmean(xe) ;
% yLabel='Niveau de la mer';
% titre ='La maree au conquet';

% load Pascal_TS;
% interval=10/60;
% time_data=(date(1): 10/(60*24):date(end))';
% interpolation=interp1(date,ti(:,1),time_data) ;
% series_data=interpolation-nanmean(interpolation);
% xLabel='Time (year, month, day, hour';
% yLabel='Temperature (C)';
% titre ='Temperature in ile de la Reunion from 21/07/2011 12h00 to 19/01/2012 00h00';


load('load_donnes_Marel.mat')
interval=20/60; % toutes les 20 minutes
time1=timeTemp;time2=timeSali;time3=timeSeaLevel;time4=timeTurbi;
data1=Temp;data2=Sali;data3=SeaLevel;data4=Turbi;
time_data=time3;
series_data=data3-nanmean(data3);
yLabel='Niveau de la mer';
titre ='Donnes Marel Carnot';

%% Plot la serie temporelle

number=length(series_data(isnan(series_data)));
percentNaN=100*(number/length(series_data));

plot(time_data,series_data,'r.');
tlabel;
xlabel(xLabel);
ylabel(yLabel);
title(titre,'FontWeight','bold');

% % Passe bande entre permin=1 jour et 
% y=passband_fastoche(time_data,series_data,1/24,3);
% figure;
% plot(time_data,y);
% tlabel;
% grid;
% 
% % apres le filtrage
% series_data=y;

[tidestruc,pout]=t_tide(series_data,'interval',interval,'start time',time_data(1));             % Latitude of obs);

% Look for amplitudes (third column):
% --> lunar (M2) and solar (S2)semi-diurnal tides
% --> lunisolar (K1) and lunar (O1) tides
 amplitudes=tidestruc.tidecon(:,1); 
 names=tidestruc.name;
 aO1=0; aK1=0; aM2=0; aS2=0;
 for i=1:length(names)
     
     if(strcmp(names(i,:),'O1  ')==1)
         display([names(i,:) '--> aO1 = ' num2str(amplitudes(i))]);
         aO1=amplitudes(i);
     end
     if(strcmp( names(i,:),'K1  ')==1)
          display([names(i,:) '--> aK1 = ' num2str(amplitudes(i))]);
          aK1=amplitudes(i);
     end
     if(strcmp( names(i,:),'M2  ')==1)
         display([names(i,:) '--> aM2 = ' num2str(amplitudes(i))]);
         aM2=amplitudes(i);
     end
    if(strcmp( names(i,:),'S2  ')==1)
         display([names(i,:) '--> aS2 = ' num2str(amplitudes(i))]);
         aS2=amplitudes(i);
    end      
 end
% Calculate Form Factor: F=(aK1+aO1)/(aM2+aS2)
F=(aK1+aO1)/(aM2+aS2);
display(['Form factor F = (aK1+aO1)/(aM2+aS2)=  '  num2str(F)]);
% Classify the tide according to the criteria
if(F > 3) 
    display('F > 3 --> Diurnal 1 High, 1 Low per day');
end
if(F < 3 && F > 0.25) 
    display('0.25 < F < 3 -->  Mixed 2 Highs, 2 Lows per day');
end
if(F <  0.25) 
    display('F < 0.25 -->  Semidiurnal 2 Highs, 2 Lows per day');
end


deltat=mean(diff(time_data)); % For Marel Carnot = 20/(24*60);
Fs=1/deltat;
L=length(pout);


figure;
clf;orient tall;
subplot(411);
plot(time_data,[series_data pout]);
line(time_data,series_data-pout,'linewi',2,'color','r');
xlabel('time axis');
ylabel('Elevation (m)');
tlabel;
text(190,5.5,'Original Time series','color','b');
text(190,4.75,'Tidal prediction from Analysis','color',[0 .5 0]);
text(190,4.0,'Original time series minus Prediction','color','r');
title('Use of t\_tide toolbox');
legend('Original Time series','Tidal prediction from Analysis','Original time series minus Prediction','location','northEast');

subplot(412);
fsig=tidestruc.tidecon(:,1)>tidestruc.tidecon(:,2); % Significant peaks
semilogy([tidestruc.freq(~fsig),tidestruc.freq(~fsig)]',[.0005*ones(sum(~fsig),1),tidestruc.tidecon(~fsig,1)]','.-r');
line([tidestruc.freq(fsig),tidestruc.freq(fsig)]',[.0005*ones(sum(fsig),1),tidestruc.tidecon(fsig,1)]','marker','.','color','b');
line(tidestruc.freq,tidestruc.tidecon(:,2),'linestyle',':','color',[0 .5 0]);
set(gca,'ylim',[.0005 1],'xlim',[0 .5]);
xlabel('frequency (cph)');
text(tidestruc.freq,tidestruc.tidecon(:,1),tidestruc.name,'rotation',45,'vertical','base');
ylabel('Amplitude (m)');
text(.27,.4,'Analyzed lines with 95% significance level');
text(.35,.2,'Significant Constituents','color','b');
text(.35,.1,'Insignificant Constituents','color','r');
text(.35,.05,'95% Significance Level','color',[0 .5 0]);

subplot(413);
errorbar(tidestruc.freq(~fsig),tidestruc.tidecon(~fsig,3),tidestruc.tidecon(~fsig,4),'.r');
hold on;
errorbar(tidestruc.freq(fsig),tidestruc.tidecon(fsig,3),tidestruc.tidecon(fsig,4),'o');
hold off;
set(gca,'ylim',[-45 360+45],'xlim',[0 .5],'ytick',[0:90:360]);
xlabel('frequency (cph)');
ylabel('Greenwich Phase (deg)');
text(.27,330,'Analyzed Phase angles with 95% CI');
text(.35,290,'Significant Constituents','color','b');
text(.35,250,'Insignificant Constituents','color','r');

subplot(414);
ysig=series_data;
yerr=series_data-pout;
nfft=389;
bd=isnan(ysig);
gd=find(~bd);
bd([1:(min(gd)-1) (max(gd)+1):end])=0;

ysig(bd)=interp1(gd,ysig(gd),find(bd)); 
[Pxs,F]=pwelch(ysig(isfinite(ysig)),hanning(nfft),ceil(nfft/2),nfft,1);
Pxs=Pxs/2;

yerr(bd)=interp1(gd,yerr(gd),find(bd)); 
[Pxe,F]=pwelch(yerr(isfinite(ysig)),hanning(nfft),ceil(nfft/2),nfft,1);
Pxe=Pxe/2;

semilogy(F,Pxs);
line(F,Pxe,'color','r');
xlabel('frequency (cph)');
ylabel('m^2/cph');
text(.17,1e4,'Spectral Estimates before and after removal of tidal energy');
text(.35,1e3,'Original (interpolated) series','color','b');
text(.35,1e2,'Analyzed Non-tidal Energy','color','r');
