function [mf]=meanf(imf,fq)
%[mf]=meanf(imf,fq)
%********************************************************************* 
% This function is to estimate the mean frequency of each imf based on the
% Fourier transform
% Input
% imf(n,k)  n is the length of f,k is each IMF frequency 
% fq        is the sampling frequency: the default value equal 1 
%
% Output
% mf         is the mean frequency definited in NE Huang 1998
%
% Written by Yongxiang Huang 5/8/2005
%******************************************************************


if nargin==1
    fq=1;
end
if iscell(imf)
    error('You should call the function imf2freq to calculate the mean frequency !')
end
if size(imf,1)<size(imf,2)
   imf=imf';
end
N=size(imf,1);



ax=imf;
for i=1:size(ax,2)-1
  x=ax(:,i);
  x=detrend(x); % modified by Yongxiang Huang 14/01/2008
  d=fft(x); % Fourier transform
  pdd=d.*conj(d)/length(d);% get the spectrum
  N=length(pdd);
  f=fq*(0:N/2)/N;%get the real frequency
  mf(i)=sum(f'.*pdd(1:length(f)))/sum(pdd(1:length(f))); % get the mean
                                                         % frequency  
end
