function y = binopdf(x,n,p)
%MATLAB Code Generation Library Function

%   Copyright 1984-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 3,'stats:binopdf:TooFewInputs');
validateattributes(x,{'numeric'},{'real'},'binopdf','x',1); %#ok<EMCA>
validateattributes(n,{'numeric'},{'real'},'binopdf','n',2); %#ok<EMCA>
validateattributes(p,{'single','double'},{'real'},'binopdf','p',3); %#ok<EMCA>
y = coder.internal.sxalloc([isfloat(x),isfloat(n),true],x,n,p);
for k = 1:numel(y)
    xk = eml_scalexp_subsref(x,k);
    nk = eml_scalexp_subsref(n,k);
    pk = eml_scalexp_subsref(p,k);
    if pk >= 0 && pk <= 1 && nk == floor(nk) && ~isnan(xk)
        if xk >= 0 && xk == floor(xk) && xk <= nk
            xf = cast(xk,class(y));
            nf = cast(nk,class(y));
            if pk == 0
                y(k) = (xk == 0);
            elseif pk == 1
                y(k) = (xk == nk);
            elseif xk == 0
                y(k) = exp(nf*log(1-pk));
            elseif xk == nk
                y(k) = exp(nf*log(pk));
            elseif nk < 10
                % Faster method that is not accurate for large n
                lny = gammaln(nf+1) - gammaln(xf+1) - ...
                    gammaln(nf-xf+1) + xf*log(pk) + ...
                    (nf - xf)*log1p(-pk);
                y(k) = exp(lny);
            else
                lc = stirlerr(nf) - stirlerr(xf) - stirlerr(nf-xf) - ...
                    binodeviance(xf,nf*pk) - binodeviance(nf-xf,nf*(1-pk));
                y(k) = exp(lc)*sqrt(nf/(2*pi*xf*(nf-xf)));
            end
        else
            y(k) = 0;
        end
    else
        y(k) = coder.internal.nan(class(y));
    end
end
