function p = fcdf(x,v1,v2,tail)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin <= 4,'stats:fcdf:TooFewInputs');
validateattributes(x,{'single','double'},{'real'},'fcdf','x',1); %#ok<EMCA>
validateattributes(v1,{'numeric'},{'real'},'fcdf','v1',2); %#ok<EMCA>
validateattributes(v2,{'numeric'},{'real'},'fcdf','v2',3); %#ok<EMCA>
if nargin < 4
    upper = false;
else
    coder.internal.prefer_const(tail);
    upper = CheckForUpper(tail);
end
p = coder.internal.sxalloc([true,isfloat(v1),isfloat(v2)],x,v1,v2);
for k = 1:numel(p)
    xk = eml_scalexp_subsref(x,k);
    if upper
        % xk = 1/max(0,xk);
        if xk <= 0
            xk = eml_guarded_inf(class(xk));
        else
            xk = 1/xk;
        end
        % v1 and v2 are swapped.
        v1k = cast(eml_scalexp_subsref(v2,k),class(p));
        v2k = cast(eml_scalexp_subsref(v1,k),class(p));
    else
        v1k = cast(eml_scalexp_subsref(v1,k),class(p));
        v2k = cast(eml_scalexp_subsref(v2,k),class(p));
    end
    if v1k > 0 && v2k > 0 && ~isnan(xk)
        if xk > 0
            if isinf(xk)
                p(k) = 1;
            elseif isinf(v1k)
                if isinf(v2k)
                    if upper
                        p(k) = (xk > 1);
                    else
                        p(k) = (xk >= 1);
                    end
                else
                    p(k) = real(gammainc(v2k/xk/2,v2k/2,'upper')); % 1 - chi2cdf(v2k/xk,v2k)
                end
            elseif isinf(v2k)
                p(k) = real(gammainc(v1k*xk/2,v1k/2,'lower')); % chi2cdf(v1k*xk,v1k)
            else
                % use A&S formula 26.6.2 to relate to incomplete beta function
                % Also use 26.5.2 to avoid cancellation by subtracting from 1
                if v2k <= xk*v1k
                    xx = v2k/(v2k + xk*v1k);
                    p(k) = real(betainc(xx,v2k/2,v1k/2,'upper'));
                else
                    num = v1k*xk;
                    xx = num/(num + v2k);
                    p(k) = real(betainc(xx,v1k/2,v2k/2,'lower'));
                end
            end
        else % xk < 0
            p(k) = 0;
        end
    else
        p(k) = coder.internal.nan(class(p));
    end
end
