function x = finv(p,v1,v2)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 3,'stats:finv:TooFewInputs');
validateattributes(p,{'single','double'},{'real'},'finv','p',1); %#ok<EMCA>
validateattributes(v1,{'numeric'},{'real'},'finv','v1',2); %#ok<EMCA>
validateattributes(v2,{'numeric'},{'real'},'finv','v2',3); %#ok<EMCA>
x = coder.internal.sxalloc([true,isfloat(v1),isfloat(v2)],p,v1,v2);
for k = 1:numel(x)
    pk = eml_scalexp_subsref(p,k);
    v1k = cast(eml_scalexp_subsref(v1,k),class(x));
    v2k = cast(eml_scalexp_subsref(v2,k),class(x));
    if v1k > 0 && v2k > 0 && pk >= 0 && pk <= 1
        if isinf(v1k)
            if isinf(v2k)
                if pk > 0
                    x(k) = 1;
                else
                    x(k) = 0;
                end
            else
                x(k) = v2k/chi2inv(1 - pk,v2k);
            end       
        elseif isinf(v2k)
            x(k) = chi2inv(pk,v1k)/v1k;
        else
            % Get the smaller of z or 1-z to give the best precision
            if pk > real(betainc(0.5,v1k/2,v2k/2,'lower'))
                zUp = real(betaincinv(pk,v2k/2,v1k/2,'upper'));
                t = (1 - zUp)/zUp;
            else
                zLo = real(betaincinv(pk,v1k/2,v2k/2,'lower'));
                t = zLo/(1 - zLo);
            end
            x(k) = t*v2k/v1k;
        end
    else
        x(k) = coder.internal.nan(class(x));
    end
end
