function [m,v]= fstat(v1,v2)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 2,'stats:fstat:TooFewInputs');
validateattributes(v1,{'numeric'},{'real'},'fstat','v1',1); %#ok<EMCA>
validateattributes(v2,{'numeric'},{'real'},'fstat','v2',2); %#ok<EMCA>
m = coder.internal.sxalloc([isfloat(v1),isfloat(v2)],v1,v2);
v = coder.nullcopy(m);
NAN = coder.internal.nan(class(m));
for k = 1:numel(m)
    v1k = cast(eml_scalexp_subsref(v1,k),class(m));
    v2k = cast(eml_scalexp_subsref(v2,k),class(m));
    if v1k > 0 && v2k > 2
        if isinf(v2k)
            if isinf(v1k)
                % If v1 = Inf and v2 = Inf, then F(v1,v2) concentrates
                % around 1 with variance 0.
                m(k) = 1;
                v(k) = 0;
            else
                % If v1 < Inf and v2 = Inf, then F(v1,v2) = chi2(v1)/v1.
                m(k) = 1;
                v(k) = 2/v1k;
            end
        else
            m(k) = v2k/(v2k - 2);
            if v2k > 4 % Variance defined only for v2 > 4
                if isinf(v1k)
                    v(k) = 2*(v2k*v2k)/((v2k - 2)*(v2k - 2)*(v2k - 4));
                else
                    v(k) = m(k)*m(k)*2*(v1k + v2k - 2)/(v1k*(v2k - 4));
                end
            else
                v(k) = NAN;
            end
        end
    else
        m(k) = NAN;
        v(k) = NAN;
    end
end
