function [p,plo,pup] = gamcdf(x,a,varargin)
%MATLAB Code Generation Library Function

%   Parameters: b,pcov,alpha,tail
%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 2,'stats:gamcdf:TooFewInputs');
coder.internal.assert(nargin <= 6,'MATLAB:maxrhs');
validateattributes(x,{'single','double'},{'real'},'gamcdf','x',1); %#ok<EMCA>
validateattributes(a,{'single','double'},{'real'},'gamcdf','a',2); %#ok<EMCA>
[upper,nparms] = CheckForUpper(varargin{:});
if nparms < 1
    b = ones(class(a));
else
    b = varargin{1};
    validateattributes(b,{'single','double'},{'real'},'gamcdf','b',3); %#ok<EMCA>
end
% More checking if we need to compute confidence bounds.
if nargout > 1
    coder.internal.errorIf(nparms < 2, ...
        'stats:gamcdf:TooFewInputsNeedCov');
    pcov = varargin{2};
    coder.internal.assert(isequal(size(pcov),[2 2]), ...
        'stats:gamcdf:BadCovarianceSize');
    if nparms < 3
        alpha = 0.05;
    else
        alpha = varargin{3};
        coder.internal.errorIf(~isnumeric(alpha) || ~isscalar(alpha) || ...
            alpha(1) <= 0 || alpha(1) >= 1,'stats:gamcdf:BadAlpha');
    end
end
p = coder.internal.sxalloc([true,true,true],x,a,b);
plo = coder.nullcopy(p);
pup = coder.nullcopy(p);
for k = 1:numel(p)
    xk = eml_scalexp_subsref(x,k);
    ak = eml_scalexp_subsref(a,k);
    bk = eml_scalexp_subsref(b,k);
    if ak >= 0 && bk > 0 && ~isnan(xk)
        if xk < 0
            xk(1) = 0;
        end
        z = xk/bk;
        if upper
            p(k) = real(gammainc(z,ak,'upper'));
        else
            p(k) = real(gammainc(z,ak,'lower'));
        end
        % Compute confidence bounds if requested.
        if nargout >= 2
            % Approximate the variance of p on the logit scale
            logitp = log(p(k)/(1 - p(k)));
            dp = 1/(p(k)*(1 - p(k))); % derivative of logit(p) w.r.t. p
            da = dgammainc(z,ak)*dp; % dlogitp/da = dp/da*dlogitp/dp
            db = -exp(ak*log(z) - z - gammaln(ak) - log(bk))*dp; % dlogitp/db = dp/db*dlogitp/dp
            varLogitp = pcov(1,1)*(da*da) + 2*pcov(1,2)*da*db + pcov(2,2)*(db*db);
            if varLogitp < 0
                plo(k) = coder.internal.nan(class(p));
                pup(k) = coder.internal.nan(class(p));
                eml_error('stats:gamcdf:BadCovariancePosSemiDef');
            else
                % Use a normal approximation on the logit scale, then
                % transform back to the original CDF scale
                halfwidth = -norminv(alpha(1)/2)*sqrt(varLogitp);
                explogitplo = exp(logitp - halfwidth);
                explogitpup = exp(logitp + halfwidth);
                plo(k) = explogitplo/(1 + explogitplo);
                pup(k) = explogitpup/(1 + explogitpup);
            end
        end
    else
        p(k) = coder.internal.nan(class(p));
        plo(k) = coder.internal.nan(class(p));
        pup(k) = coder.internal.nan(class(p));
    end
end
