function p = gevcdf(x,varargin)
%MATLAB Code Generation Library Function

%   Parameters: k,sigma,mu,tail

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 1,'stats:gevcdf:TooFewInputs');
coder.internal.assert(nargin <= 5,'MATLAB:maxrhs');
validateattributes(x,{'single','double'},{'real'},'gevcdf','x',1); %#ok<EMCA>
[upper,nparms] = CheckForUpper(varargin{:});
if nparms < 1
    k = zeros(class(x));
else
    k = varargin{1};
    validateattributes(k,{'single','double'},{'real'},'gevcdf','k',2); %#ok<EMCA>
end
if nparms < 2
    sigma = ones(class(x));
else
    sigma = varargin{2};
    validateattributes(sigma,{'single','double'},{'real'},'gevcdf','sigma',3); %#ok<EMCA>
end
if nparms < 3
    mu = zeros(class(x));
else
    mu = varargin{3};
    validateattributes(mu,{'single','double'},{'real'},'gevcdf','mu',4); %#ok<EMCA>
end
p = coder.internal.sxalloc([true,true,true,true],x,k,sigma,mu);
for j = 1:numel(p)
    xj = eml_scalexp_subsref(x,j);
    kj = eml_scalexp_subsref(k,j);
    sigmaj = eml_scalexp_subsref(sigma,j);
    muj = eml_scalexp_subsref(mu,j);
    if sigmaj > 0
        zj = (xj - muj)/sigmaj;
        if abs(kj) < eps(class(p))
            if upper
                p(j) = -expm1(-exp(-zj));
            else
                p(j) = exp(-exp(-zj));
            end
        else
            tj = zj*kj;
            if upper
                if tj <= -1
                    p(j) = (kj >= 0);
                else
                    p(j) = -expm1(-exp(-(1/kj)*log1p(tj)));
                end
            else
                if tj <= -1
                    p(j) = (kj < 0);
                else
                    p(j) = exp(-exp(-(1/kj)*log1p(tj))); % exp(-(1 + k*z)^(-1/k));
                end
            end
        end
    else
        p(j) = coder.internal.nan(class(p));
    end
end
