function p = hygecdf(x,m,k,n,tail)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 4,'stats:hygecdf:TooFewInputs');
validateattributes(x,{'single','double'},{'real'},'hygecdf','x',1); %#ok<EMCA>
validateattributes(m,{'numeric'},{'real'},'hygecdf','m',2); %#ok<EMCA>
validateattributes(k,{'numeric'},{'real'},'hygecdf','k',3); %#ok<EMCA>
validateattributes(n,{'numeric'},{'real'},'hygecdf','n',4); %#ok<EMCA>
if nargin < 5
    upper = false;
else
    coder.internal.prefer_const(tail);
    upper = CheckForUpper(tail);
end
p = coder.internal.sxalloc([true,isfloat(m),isfloat(k),isfloat(n)],x,m,k,n);
for j = 1:numel(p)
    xj = eml_scalexp_subsref(x,j);
    mj = cast(eml_scalexp_subsref(m,j),class(p));
    kj = cast(eml_scalexp_subsref(k,j),class(p));
    nj = cast(eml_scalexp_subsref(n,j),class(p));
    if upper
        xj = nj - floor(xj) - 1;
        kj = mj - kj;
    end
    if mj >= 0 && kj >= 0 && nj >= 0 && floor(mj) == mj && ...
            floor(kj) == kj && floor(nj) == nj && ...
            nj <= mj && kj <= mj && ~isnan(xj)
        mjmkj = mj - kj;
        njmxj = nj - xj;
        if xj < 0 || mjmkj - njmxj + 1 <= 0
            p(j) = 0;
        elseif xj >= nj || xj >= kj
            p(j) = 1;
        else
            % For accuracy, for x values that are larger than the mean,
            % compute the upper tail 1-p instead of the lower tail p.  This
            % will tend to increase the number of significant bits in the
            % result.
            if xj*mj <= kj*nj
                p(j) = F(floor(xj),mj,kj,nj);
            else
                p(j) = 1 - F(nj-floor(xj)-1,mj,mjmkj,nj);
            end
        end
    else
        p(j) = coder.internal.nan(class(p));
    end
end

%--------------------------------------------------------------------------

function p = F(x,m,k,n)
coder.internal.prefer_const(m,k,n);
% Hypergeometric cdf without error checking
den = hygepdf(x,m,k,n);
ZERO = zeros(class(den));
ONE = ones(class(den));
% compute hygecdf(x,m,k,n)/hygepdf(x,m,k,n) with a series whose terms can
% be computed recursively, backwards.
c = m - k - n + 1;
product = ONE;
ratio = ZERO;
for j = x-1:-1:0
    term = ((j + 1)*(j + c))/((n - j)*(k - j));
    product = product*term;
    ratio = ratio + product;
end
ratio = ratio + 1;
% Compute the return value and prevent roundoff from resulting in p > 1.
p = ratio*den;
if p > 1
    p(1) = 1;
end

%--------------------------------------------------------------------------
