function k = kurtosis(x,flag,dim)
%MATLAB Code Generation Toolbox Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin > 0,'MATLAB:minrhs');
if nargin == 3
    coder.internal.prefer_const(dim);
    if isempty(flag)
        k = kurtosis(x,true,dim);
        return
    end
    % We will not support an empty dim input just to return [] like MATLAB.
    eml_assert_valid_dim(dim);
else
    if eml_is_const(size(x)) && isequal(size(x),[0,0])
        k = coder.internal.nan(class(x));
        return
    end
    dim = eml_const_nonsingleton_dim(x);
    if nargin == 1
        flag = true;
    end
    if eml_is_const(size(x)) && isequal(x,[])
        k = coder.internal.nan(class(x));
        return
    end
end
% Center X, compute its fourth and second moments, and compute the
% uncorrected kurtosis. First call to nanmean goes directly to
% nan_sum_or_mean to get the non-nan count output.
[m1,n] = nan_sum_or_mean('mean',x,dim);
x0 = bsxfun(@minus,x,m1);
x0 = x0.*x0;
s2 = nanmean(x0,dim); % this is the biased variance estimator
x0 = x0.*x0;
m4 = nanmean(x0,dim);
k = m4./(s2.*s2);
if flag == 0
    % Bias correct the kurtosis.
    for j = 1:numel(k)
        if n(j) >= 4
            nj = cast(n(j),class(k));
            k(j) = ((nj + 1)*k(j) - 3*(nj - 1))*(nj - 1)/ ...
                ((nj - 2)*(nj - 3)) + 3;
        else
            % bias correction is not defined for n < 4.
            k(j) = coder.internal.nan(class(k));
        end
    end
end
