function [x,xlo,xup] = logninv(p,mu,sigma,pcov,alpha)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 1,'stats:logninv:TooFewInputsP');
if nargin < 2
    mu = zeros(class(p));
end
if nargin < 3
    sigma = ones(class(p));
end
validateattributes(p,{'single','double'},{'real'},'logninv','p',1); %#ok<EMCA>
validateattributes(mu,{'single','double'},{'real'},'logninv','mu',2); %#ok<EMCA>
validateattributes(sigma,{'single','double'},{'real'},'logninv','sigma',3); %#ok<EMCA>
CONFINT = nargout >= 2;
if CONFINT
    coder.internal.errorIf(nargin < 4, ...
        'stats:logninv:TooFewInputsCovariance');
    coder.internal.assert(isequal(size(pcov),[2 2]), ...
        'stats:logninv:BadCovarianceSize');
    if nargin < 5
        alpha = 0.05;
    else
        coder.internal.errorIf(~isnumeric(alpha) || ~isscalar(alpha) || ...
            alpha(1) <= 0 || alpha(1) >= 1,'stats:logninv:BadAlpha');
    end
    normz = sqrt(2)*erfcinv(alpha); % -norminv(alpha/2);
end
x = coder.internal.sxalloc([true,true,true],p,mu,sigma);
if CONFINT
    xlo = coder.nullcopy(x);
    xup = coder.nullcopy(x);
end
for k = 1:numel(x)
    pk = eml_scalexp_subsref(p,k);
    muk = eml_scalexp_subsref(mu,k);
    sigmak = eml_scalexp_subsref(sigma,k);
    if sigmak > 0 && pk >= 0 && pk <= 1
        logx0 = -sqrt(2)*erfcinv(2*pk);
        x(k) = exp(sigmak*logx0 + muk);
        if CONFINT
            xvar = pcov(1,1) + 2*pcov(1,2)*logx0 + pcov(2,2)*(logx0*logx0);
            coder.internal.errorIf(xvar < 0, ...
                'stats:logninv:BadCovarianceSymPos');
            halfwidth = normz*sqrt(xvar);
            xlo(k) = x(k)*exp(-halfwidth);
            xup(k) = x(k)*exp(halfwidth);
        end
    else
        x(k) = coder.internal.nan(class(x));
        if CONFINT
            xlo(k) = coder.internal.nan(class(x));
            xup(k) = coder.internal.nan(class(x));
        end
    end
end
