function y = mnpdf(x,p)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 2,'MATLAB:minrhs');
% If p is a column that can be interpreted as a single vector of MN
% probabilities (non-empty and sums to one), transpose it to a row.
% Otherwise, treat as a matrix with one category.
if iscolumn(p) && numel(p) > 1 && ...
        abs(sum(p(:)) - 1) <= numel(p)*eps(class(p))
    % Implicit transpose
    nrowsp = 1;
    ncolsp = numel(p);
    expandp = true;
    if iscolumn(x) && numel(x) > 1
        nrowsx = 1;
        ncolsx = numel(x);
        expandx = true;
    else
        [nrowsx,ncolsx] = size(x);
        expandx = (nrowsx == 1);
    end
    mout = nrowsp;
else
    [nrowsx,ncolsx] = size(x);
    [nrowsp,ncolsp] = size(p);
    if nrowsx == 1 && nrowsp ~= 1;
        expandx = true;
        expandp = false;
        mout = nrowsp;
    else
        expandx = false;
        expandp = nrowsx ~= 1 && nrowsp == 1; % p is a vector.
        mout = nrowsx;
    end
end
coder.internal.errorIf(ncolsx < 1,'stats:mnpdf:NoCategories');
coder.internal.errorIf(ncolsp ~= ncolsx,'stats:mnpdf:ColSizeMismatch');
coder.internal.assert(nrowsp == nrowsx || expandx || expandp, ...
    'stats:mnpdf:RowSizeMismatch');
% Do binary scalar expansion if the number of rows == 1 for either input.
y = coder.nullcopy(zeros(mout,1,'like',eml_scalar_eg(x,p)));
nBad = false;
pBad = false;
xBad = false;
c = eml_scalar_eg(x);
if expandx
    % Hoist processx() out of the loop.
    [xBad,nBad,c] = processx(x,1,1,ncolsx);
elseif expandp
    % Hoist processp() out of the loop.
    pBad = processp(p,1,1,ncolsp);
end
for i = 1:mout
    if ~expandp
        pBad = processp(p,i,nrowsp,ncolsx);
    end
    if ~pBad && ~expandx
        [xBad,nBad,c] = processx(x,i,nrowsx,ncolsx);
    end
    if pBad || nBad
        y(i) = coder.internal.nan(class(y));
    elseif xBad
        y(i) = 0;
    else
        xlogp = eml_scalar_eg(y);
        if expandp && expandx
            for j = 1:ncolsx
                if p(j) > 0
                    xlogp = xlogp + x(j)*log(p(j));
                end
            end
        elseif expandp
            for j = 1:ncolsx
                if p(j) > 0
                    xlogp = xlogp + x(i,j)*log(p(j));
                end
            end
        elseif expandx
            for j = 1:ncolsx
                if p(i,j) > 0
                    xlogp = xlogp + x(j)*log(p(i,j));
                end
            end
        else
            for j = 1:ncolsx
                if p(i,j) > 0
                    xlogp = xlogp + x(i,j)*log(p(i,j));
                end
            end
        end
        y(i) = exp(c + xlogp);
    end
end

%--------------------------------------------------------------------------

function [xBad,nBad,c] = processx(x,jstart,stride,nx)
xBad = false;
n = eml_scalar_eg(x);
jend = jstart + (nx - 1)*stride;
for j = jstart:stride:jend
    if x(j) < 0 || x(j) ~= floor(x(j))
        xBad = true;
        break
    end
    n = n + x(j);
end
nBad = n < 0 || floor(n) ~= n;
if ~(xBad || nBad)
    sumgx = eml_scalar_eg(x);
    for j = jstart:stride:jend
        sumgx = sumgx + gammaln(x(j) + 1);
    end
    c = gammaln(n + 1) - sumgx;
else
    c = 0;
end

%--------------------------------------------------------------------------

function pBad = processp(p,jstart,stride,np)
pBad = false;
psum = eml_scalar_eg(p);
jend = jstart + (np - 1)*stride;
for j = jstart:stride:jend
    if p(j) < 0 || p(j) > 1
        pBad = true;
        break
    end
    psum = psum + p(j);
end
pBad = pBad || (abs(psum - 1) > np*eps(class(p)));

%--------------------------------------------------------------------------
