function x = ncfinv(p,nu1,nu2,delta)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 4,'stats:ncfinv:TooFewInputs');
validateattributes(p,{'single','double'},{'real'},'ncfinv','p',1); %#ok<EMCA>
validateattributes(nu1,{'numeric'},{'real'},'ncfinv','v1',2); %#ok<EMCA>
validateattributes(nu2,{'numeric'},{'real'},'ncfinv','v2',3); %#ok<EMCA>
validateattributes(p,{'single','double'},{'real'},'ncfinv','p',1); %#ok<EMCA>
x = coder.internal.sxalloc([true,isfloat(nu1),isfloat(nu2),true,],p,nu1,nu2,delta);
crit = sqrt(eps(class(x)));
for k = 1:numel(x)
    pk = eml_scalexp_subsref(p,k);
    nu1k = cast(eml_scalexp_subsref(nu1,k),class(x));
    nu2k = cast(eml_scalexp_subsref(nu2,k),class(x));
    deltak = eml_scalexp_subsref(delta,k);
    if nu1k > 0 && nu2k > 0 && pk >= 0 && pk <= 1 && deltak >= 0
        if deltak == 0
            x(k) = finv(pk,nu1k,nu2k);
        elseif pk == 0
            x(k) = 0;
        elseif pk == 1
            x(k) = coder.internal.inf(class(x));
        else
            % Start at the mean, if the mean exists (if nu2>2)
            y = nu2k*(nu1k + deltak)/(nu1k*max(1,nu2k-2));
            % Newton's Method.
            % Permit no more than count_limit iterations.
            count_limit = 100;
            count = 0;
            h = y;
            % Iterate until the last update is very small compared to x,
            % or we have made too many iterations
            oldh = zeros(class(h));
            sgnoldh = sign(oldh);
            F = ncfcdf(y,nu1k,nu2k,deltak);
            noconvergence = true;
            while count < count_limit
                count = count + 1;
                f = ncfpdf(y,nu1k,nu2k,deltak);
                h = (F - pk)/f;
                % If iterations appear to be oscillating, damp them out
                sgnh = sign(h);
                if sgnh == -sgnoldh;
                    h = sgnh*min(abs(h),abs(oldh))/2;
                end
                % Avoid stepping too far
                newy = max(y/5,min(5*y,y - h));
                % Back off if the step gives a worse result
                newF = ncfcdf(newy,nu1k,nu2k,deltak);
                while true
                    if ~((abs(newF - pk) > abs(F - pk)*(1 + crit)) && ...
                            (abs(y - newy) > crit*y))
                        break
                    end
                    newy = 0.5*(newy + y);
                    newF = ncfcdf(newy,nu1k,nu2k,deltak);
                end
                x(k) = newy;
                % See which elements have not yet converged
                h = y - newy;
                if ~(abs(h) > crit*abs(y))
                    noconvergence = false;
                    break
                end
                % Save parameters for only these elements
                F = newF;
                y = newy;
                oldh = h;
                sgnoldh = sign(oldh);
            end
            if noconvergence
                eml_warning('stats:ncfinv:NotConverge');
                % fprintf([getString(message('stats:ncfinv:LastStep')) num2str(h(:)') '\n']);
            end
        end
    else
        x(k) = coder.internal.nan(class(x));
    end
end
