function y = ncfpdf(x,nu1,nu2,delta)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 4,'stats:ncfpdf:TooFewInputs');
validateattributes(x,{'single','double'},{'real'},'ncfpdf','x',1); %#ok<EMCA>
validateattributes(nu1,{'numeric'},{'real'},'ncfpdf','nu1',2); %#ok<EMCA>
validateattributes(nu2,{'numeric'},{'real'},'ncfpdf','nu2',3); %#ok<EMCA>
validateattributes(delta,{'single','double'},{'real'},'ncfpdf','delta',4); %#ok<EMCA>
y = coder.internal.sxalloc([true,isfloat(nu1),isfloat(nu2),true],x,nu1,nu2,delta);
for k = 1:numel(y)
    xk = eml_scalexp_subsref(x,k);
    nu1k = cast(eml_scalexp_subsref(nu1,k),class(y));
    nu2k = cast(eml_scalexp_subsref(nu2,k),class(y));
    deltak = eml_scalexp_subsref(delta,k);
    if nu1k > 0 && nu2k > 0 && deltak >= 0 && ~isnan(xk)
        if xk < 0
            y(k) = 0;
        elseif xk == 0
            if nu1k < 2
                y(k) = coder.internal.inf(class(y));
            elseif nu1k > 2
                y(k) = 0;
            else
                y(k) = exp(-deltak/2);
            end
        elseif deltak == 0
            y(k) = fpdf(xk,nu1k,nu2k);
        else
            y(k) = ncfpdfpos(xk,nu1k,nu2k,deltak,class(y));
        end
    else
        % Special case for invalid parameters
        y(k) = coder.internal.nan(class(y));
    end
end

%--------------------------------------------------------------------------

function y = ncfpdfpos(x,nu1,nu2,delta,cls)
% ncfpdf assuming strictly positive parameters.
% To simplify computation, pre - divide nu1, nu2 and delta
nu1 = nu1/2;
nu2 = nu2/2;
delta = delta/2;
% Use z and scaled x for convenience
z = nu1*x/(nu1*x + nu2);
z1 = nu2/(nu1*x + nu2);
xs = delta*z;
intnu2 = (nu2 == floor(nu2));
% Make constants
lnsr2pi = cast(log(sqrt(2*pi)),cls);
ZERO = zeros(cls);
ONE = ones(cls);
% Find max K at which we start the recursion series
K = ZERO;
rsum = ZERO;
% Integer nu2
if intnu2
    if xs <= nu1/nu2;
        %smallx, K=0
    elseif xs >= nu2*(nu1 + nu2 - 1)
        %largex, K=nu2
        K = nu2;
    else
        % Solve eqn for K
        d = 0.5*(1 - xs - nu1);
        K = floor(d + sqrt(d*d + xs*(nu2 + 1)));
    end
    if K == nu2
        % Case K == nu2
        if z < 0.9
            termK = (nu1 + nu2 - 1)*log(z);
        else
            termK = (nu1 + nu2 - 1)*log1p(-z1);
        end
    elseif nu1 + K <= 1
        % Case K == 0
        termK = stirlerr(nu1 + nu2) ...
            - stirlerr(nu1) - stirlerr(nu2) ...
            - binodeviance(nu1,(nu1 + nu2)*z) ...
            - binodeviance(nu2,(nu1 + nu2)*z1);
    else
        % All K's but K==nu2 or K==0
        termK = stirlerr(nu1 + nu2 - 1) ...
            - stirlerr(nu1 + K - 1) ...
            - stirlerr(nu2 - K) ...
            - binodeviance(nu1 + K - 1,(nu1 + nu2 - 1)*z) ...
            - binodeviance(nu2 - K,(nu1 + nu2 - 1)*z1);
    end
    % Poisson density for the leading term
    x1 = delta*z1;
    if K <= x1*realmin(cls)
        y = termK - x1;
    else
        y = termK - lnsr2pi - 0.5*log(K) ...
            - stirlerr(K) - binodeviance(K,x1);
    end
    % Sum recursively downwards
    term = ONE;
    k = K;
    while k > 0
        k = k - 1;
        term = term*(k + 1)*(k + nu1)/(nu2 - k)/xs;
        if ~(term >= eps(rsum))
            break
        end
        rsum = rsum + term;
    end
    % Sum recursively upwards
    term = ONE;
    k = K;
    while k < nu2
        term = term*xs*(nu2 - k)/(k + nu1)/(k + 1);
        if ~(term >= eps(rsum))
            break
        end
        rsum = rsum + term;
        k = k + 1;
    end
else % Non - integer nu2
    if xs > nu1/(nu1 + nu2)
        % Compute K for large x. Otherwise set K to 0.
        d = 0.5*(1 + xs - nu1);
        K = floor(d + sqrt(d*d + xs*(nu1 + nu2 - 1)));
    end
    if (nu1 + K) <= 1 % Case for K==0
        termK = stirlerr(nu1 + nu2) ...
            - stirlerr(nu1) - stirlerr(nu2) ...
            - binodeviance(nu1,(nu1 + nu2)*z) ...
            - binodeviance(nu2,(nu1 + nu2)*z1);
    else % Case for K~=0
        termK = stirlerr(nu1 + nu2 + K - 1) ...
            - stirlerr(nu1 + K - 1) - stirlerr(nu2) ...
            - binodeviance(nu1 + K - 1,(nu1 + nu2 + K - 1)*z) ...
            - binodeviance(nu2,(nu1 + nu2 + K - 1)*z1);
    end
    % Poisson density at the leading term
    if K <= delta*realmin(cls)
        y = termK - delta;
    else
        y = termK - lnsr2pi - 0.5*log(K) ...
            - stirlerr(K) - binodeviance(K,delta);
    end
    % Sum recursively downwards
    term = ONE;
    k = K;
    while k > 0
        k = k - 1;
        term = term*(k + 1)*(k + nu1)/(k + nu1 + nu2)/xs;
        if ~(term >= eps(rsum))
            break
        end
        rsum = rsum + term;
    end
    % Sum recursively upwards
    term = ONE;
    k = K;
    while true
        term = term*xs*(k + nu1 + nu2)/(k + nu1)/(k + 1);
        if ~(term >= eps(rsum))
            break
        end
        rsum = rsum + term;
        k = k + 1;
    end
end
% Use the recursively accumulated sum and the leading term to compute the
% density
if (nu1 + K) <= 1
    y = exp(y)*(1 + rsum)*sqrt(nu1*nu2/(nu1 + nu2)/(2*pi))/x;
elseif intnu2
    if K == nu2
        y = exp(y)*(1 + rsum)*nu1*z1;
    else
        y = exp(y)*(1 + rsum)*nu1*z1*sqrt((nu1 + nu2 - 1)/(nu2 - K)/(nu1 + K - 1)/(2*pi));
    end
else
    y = exp(y)*(1 + rsum)*nu1*z1*sqrt((nu1 + nu2 + K - 1)/nu2/(nu1 + K - 1)/(2*pi));
end

%--------------------------------------------------------------------------
