function y = nctpdf(x,nu,delta)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 3,'stats:nctpdf:TooFewInputs');
validateattributes(x,{'single','double'},{'real'},'nctpdf','x',1); %#ok<EMCA>
validateattributes(nu,{'numeric'},{'real'},'nctpdf','nu',2); %#ok<EMCA>
validateattributes(delta,{'single','double'},{'real'},'nctpdf','delta',3); %#ok<EMCA>
y = coder.internal.sxalloc([true,isfloat(nu),true],x,nu,delta);
for k = 1:numel(y)
    xk = eml_scalexp_subsref(x,k);
    nuk = cast(eml_scalexp_subsref(nu,k),class(y));
    deltak = eml_scalexp_subsref(delta,k);
    if nuk > 0 && isfinite(nuk) && isfinite(deltak) && ~isnan(xk)
        if ~isfinite(xk)
            y(k) = 0;
        elseif xk < 0
            % Negative data -- use left tail of CDF to get PDF.
            y(k) = (nuk/xk)*( ...
                nctcdf(xk*sqrt((nuk+2)/nuk),nuk+2,deltak) - ...
                nctcdf(xk,nuk,deltak));
        elseif xk > 0
            % Positive data -- reflect about zero and use left tail of
            % reflected CDF.
            y(k) = (-nuk/xk)*( ...
                nctcdf(-xk*sqrt((nuk+2)/nuk),nuk+2,-deltak) - ...
                nctcdf(-xk,nuk,-deltak));
        else
            % Zero is a special case -- use (single term) power series.
            y(k) = exp(-0.5*deltak*deltak - 0.5*log(pi*nuk) + ...
                gammaln(0.5*(nuk+1)) - gammaln(0.5*nuk));
        end
    else
        y(k) = coder.internal.nan(class(y));
    end
end
