function p = ncx2cdf(x,v,delta,tail)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 3,'stats:ncx2cdf:TooFewInputs');
validateattributes(x,{'single','double'},{'real'},'ncx2cdf','x',1); %#ok<EMCA>
validateattributes(v,{'numeric'},{'real'},'ncx2cdf','v',2); %#ok<EMCA>
validateattributes(delta,{'single','double'},{'real'},'ncx2cdf','delta',3); %#ok<EMCA>
if nargin < 4
    upper = false;
    tail = 'lower';
else
    coder.internal.prefer_const(tail);
    upper = CheckForUpper(tail);
end
p = coder.internal.sxalloc([true,isfloat(v),true],x,v,delta);
for k = 1:numel(p)
    xk = eml_scalexp_subsref(x,k);
    vk = cast(eml_scalexp_subsref(v,k),class(p));
    deltak = eml_scalexp_subsref(delta,k);
    if vk >= 0 && deltak >= 0 && ~isnan(xk)
        if xk < 0
            p(k) = upper;
        elseif xk == 0
            if vk > 0
                p(k) = upper;
            else
                if upper
                    p(k) = -expm1(-deltak/2);
                else
                    p(k) = exp(-deltak/2);
                end
            end
        elseif isinf(xk)
            p(k) = ~upper;
        elseif deltak == 0
            p(k) = chi2cdf(xk,vk,tail);
        else
            p(k) = ncx2cdfpos(xk,vk,deltak,class(p),tail);
        end
    else
        p(k) = coder.internal.nan(class(p));
    end
end

%--------------------------------------------------------------------------

function p = ncx2cdfpos(x,v,delta,cls,tail)
% ncx2cdf assuming 0 < x < inf, v >= 0, delta > 0.
coder.inline('always');
coder.internal.prefer_const(tail);
taill = lower(tail); % gammainc is case sensitive with 'upper' and 'lower'.
ZERO = zeros(cls);
ONE = ones(cls);
eps1 = eps(cls);
rmin = realmin(cls);
delta = delta/2;
v = v/2;
x = x/2;
% Compute Chernoff bounds
e0 = log(rmin);
e1 = log(eps1/4); % 1 - eps/4 is the smallest value equal to 1
t = 1 - (v + sqrt(v*v + 4*delta*x))/(2*x);
q = delta*t/(1 - t) - v*log(1 - t) - t*x;
if x < delta + v && q < e0
    p = ZERO;
    return
end
if x > delta + v && q < e1
    p = ONE;
    return
end
% Find index K of the maximal term in the summation series.
% K1 and K2 are lower and upper bounds for K, respectively.
%
% gammaincratio requires that the 2nd argument be above 1.
%
% Indexing of terms in the summation series starts at 0.
vpx = v + x;
K1 = ceil((sqrt(vpx*vpx + 4*x*delta) - vpx)/2);
if K1 > 1
    K = floor(delta*gammaincratio(x,K1));
    if ~isfinite(K)
        K = K1;
    end
else
    K = ZERO;
end
% Find Poisson and Poisson*chi2cdf parts for the maximal terms in the
% summation series.
pois = poisspdf(K,delta);
full = pois*real(gammainc(x,v + K,taill));
% Sum the series. First go downward from K and then go upward.
% The term for K is added afterwards - it is not included in either sum.
% Every term is a product of Poisson density and gamma cdf.
sumK = ZERO;
% Downward. poisspdf(k - 1,delta)/poisspdf(k,delta) = k/delta
poisterm = pois;
fullterm = full;
k = K;
tau = ZERO;
while k > 0 && fullterm > tau
    poisterm = poisterm*k/delta;
    k = k - 1;
    fullterm = poisterm*real(gammainc(x,v + k,taill));
    sumK = sumK + fullterm;
    tau = eps(sumK);
end
% Upward. poisspdf(k + 1,delta)/poisspdf(k,delta) = delta/(k + 1)
poisterm = pois;
fullterm = full;
k = K;
tau = ZERO;
while fullterm > tau
    k = k + 1;
    poisterm = poisterm*delta/k;
    fullterm = poisterm*real(gammainc(x,v + k,taill));
    sumK = sumK + fullterm;
    tau = eps(sumK);
end
% Get probabilities
p = full + sumK;
if p > 1
    p = ONE;
end

%--------------------------------------------------------------------------

function r = gammaincratio(x,s)
% GAMMAINCRATIO Ratio of incomplete gamma function values at S and S-1.
%    R=GAMMAINCRATIO(X,S) computes GAMMAINC(X,S)/GAMMAINC(X,S-1). S
%    must be greater or equal to 1. X and S must be scalars.
%   Copyright 2012 The MathWorks, Inc.
if s < 2 || s <= x
    r = real(gammainc(x,s))/real(gammainc(x,s-1));
else
    r = real(gammainc(x,s,'scaledlower')) / ...
        real(gammainc(x,s-1,'scaledlower'))*x/s;
end

%--------------------------------------------------------------------------
