function [p,plo,pup] = normcdf(x,varargin)
%MATLAB Code Generation Library Function

%   Parameters: mu,sigma,pcov,alpha,tail

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 1,'stats:normcdf:TooFewInputsX');
coder.internal.assert(nargin <= 6,'MATLAB:maxrhs');
validateattributes(x,{'single','double'},{'real'},'normcdf','x',1); %#ok<EMCA>
[upper,nparms] = CheckForUpper(varargin{:});
if nparms < 1
    mu = zeros(class(x));
else
    mu = varargin{1};
    validateattributes(mu,{'single','double'},{'real'},'normcdf','mu',2); %#ok<EMCA>
end
if nparms < 2
    sigma = ones(class(x));
else
    sigma = varargin{2};
    validateattributes(sigma,{'single','double'},{'real'},'normcdf','sigma',3); %#ok<EMCA>
end
% More checking if we need to compute confidence bounds.
CONFINT = nargout >= 2;
if CONFINT
    coder.internal.errorIf(nparms < 3, ...
        'stats:normcdf:TooFewInputsCovariance');
    pcov = varargin{3};
    coder.internal.assert(isequal(size(pcov),[2 2]), ...
        'stats:normcdf:BadCovarianceSize');
    if nparms < 4
        alpha = 0.05;
    else
        alpha = varargin{4};
        coder.internal.errorIf(~isnumeric(alpha) || ~isscalar(alpha) || ...
            alpha(1) <= 0 || alpha(1) >= 1,'stats:normcdf:BadAlpha');
    end
    normz = sqrt(2)*erfcinv(alpha); % -norminv(alpha/2);
end
p = coder.internal.sxalloc([true,true,true],x,mu,sigma);
if CONFINT
    plo = coder.nullcopy(p);
    pup = coder.nullcopy(p);
end
for k = 1:numel(p)
    xk = eml_scalexp_subsref(x,k);
    muk = eml_scalexp_subsref(mu,k);
    sigmak = eml_scalexp_subsref(sigma,k);
    if sigmak == 0
        if xk < muk
            p(k) = 0;
            if CONFINT
                plo(k) = 0;
                pup(k) = 0;
            end
        elseif xk > muk
            p(k) = 1;
            if CONFINT
                plo(k) = 1;
                pup(k) = 1;
            end
        else
            p(k) = ~upper;
            if CONFINT
                plo(k) = ~upper;
                pup(k) = ~upper;
            end
        end
    elseif sigmak > 0
        zk = (xk - muk)/sigmak;
        if upper
            zk = -zk;
        end
        % Use the complementary error function, rather than .5*(1+erf(z/sqrt(2))),
        % to produce accurate near-zero results for large negative x.
        p(k) = 0.5*erfc(-zk/sqrt(2));
        % Compute confidence bounds if requested.
        if CONFINT
            zvar = (pcov(1,1) + 2*pcov(1,2)*zk + pcov(2,2)*(zk*zk)) / ...
                (sigmak*sigmak);
            coder.internal.errorIf(zvar<0, ...
                'stats:normcdf:BadCovarianceSymPos');
            halfwidth = normz*sqrt(zvar);
            zlo = zk - halfwidth;
            zup = zk + halfwidth;
            plo(k) = 0.5*erfc(-zlo/sqrt(2));
            pup(k) = 0.5*erfc(-zup/sqrt(2));
        end
    else
        p(k) = coder.internal.nan(class(p));
        if CONFINT
            plo(k) = coder.internal.nan(class(p));
            pup(k) = coder.internal.nan(class(p));
        end
    end
end
