function x = tinv(p,v)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 2,'stats:tinv:TooFewInputs');
validateattributes(p,{'single','double'},{'real'},'tinv','p',1); %#ok<EMCA>
validateattributes(v,{'numeric'},{'real'},'tinv','v',2); %#ok<EMCA>
x = coder.internal.sxalloc([true,isfloat(v)],p,v);
for k = 1:numel(x)
    pk = eml_scalexp_subsref(p,k);
    vk = eml_scalexp_subsref(v,k);
    if vk > 0 && 0 <= pk && pk <= 1
        vf = cast(vk,class(x));
        if pk == 0
            x(k) = -coder.internal.inf(class(x));
        elseif pk == 1
            x(k) = coder.internal.inf(class(x));
        elseif vk == 1
            x(k) = tan(pi*(pk - 0.5));
        elseif vk < 1000
            % For small d.f., call betaincinv which uses Newton's method
            q = pk - 0.5;
            absq = abs(q);
            if absq < 0.25
                % for z close to 1, compute 1-z directly to avoid roundoff
                oneminusz = real(betaincinv(2*absq,0.5,vf/2,'lower'));
                z = 1 - oneminusz;
            else
                z = real(betaincinv(2*absq,vf/2,0.5,'upper'));
                oneminusz = 1 - z;
            end
            x(k) = sign(q)*sqrt(vf*(oneminusz/z));
        else
            % For large d.f., use Abramowitz & Stegun formula 26.7.5
            xn = norminv(pk);
            xn3 = xn^3;
            xn5 = xn^5;
            xn7 = xn^7;
            xn9 = xn^9;
            x(k) = xn + (xn3 + xn)/(4*vf) + ...
                (5*xn5 + 16*xn3 + 3*xn)/(96*vf^2) + ...
                (3*xn7 + 19*xn5 + 17*xn3 - 15*xn)/(384*vf^3) + ...
                (79*xn9 + 776*xn7 + 1482*xn5 - 1920*xn3 - 945*xn)/(92160*vf^4);
        end
    else
        x(k) = coder.internal.nan(class(x));
    end
end
