function [x,xlo,xup] = wblinv(p,A,B,pcov,alpha)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 1,'MATLAB:minrhs');
if nargin < 2
    A = 1;
end
if nargin < 3
    B = 1;
end
validateattributes(p,{'single','double'},{'real'},'wblinv','p',1); %#ok<EMCA>
validateattributes(A,{'single','double'},{'real'},'wblinv','A',2); %#ok<EMCA>
validateattributes(B,{'single','double'},{'real'},'wblinv','B',3); %#ok<EMCA>
% More checking if we need to compute confidence bounds.
CONFINT = nargout >= 2;
if CONFINT
    coder.internal.errorIf(nargin < 4, ...
        'stats:wblinv:MustProvideCovMatrix');
    coder.internal.assert(isequal(size(pcov),[2 2]), ...
        'stats:wblinv:BadCovariance');
    if nargin < 5
        alpha = 0.05;
    else
        coder.internal.errorIf(~isnumeric(alpha) || ~isscalar(alpha) || ...
            alpha(1) <= 0 || alpha(1) >= 1,'stats:wblinv:BadAlpha');
    end
    normz = sqrt(2)*erfcinv(alpha); % -norminv(alpha/2);
end
x = coder.internal.sxalloc([true,true,true],p,A,B);
if CONFINT
    xlo = coder.nullcopy(x);
    xup = coder.nullcopy(x);
end
for k = 1:numel(x)
    pk = eml_scalexp_subsref(p,k);
    Ak = eml_scalexp_subsref(A,k);
    Bk = eml_scalexp_subsref(B,k);
    if Ak > 0 && Bk > 0 && 0 <= pk && pk <= 1
        if pk == 0
            x(k) = 0;
            if CONFINT
                xlo(k) = 0;
                xup(k) = 0;
            end
        elseif pk == 1
            x(k) = coder.internal.inf(class(x));
            if CONFINT
                xlo(k) = coder.internal.inf(class(x));
                xup(k) = coder.internal.inf(class(x));
            end
        else
            qk = -log(1 - pk);
            x(k) = Ak*qk^(1/Bk);
            if CONFINT
                % Work on extreme value scale (log scale).
                logx = log(x(k));
                logq = log(qk);
                dA = 1/Ak;
                dB = -1/(Bk*Bk);
                dBlogq = dB*logq;
                logxvar = pcov(1,1)*(dA*dA) + 2*pcov(1,2)*(dA*dB)*logq + pcov(2,2)*(dBlogq*dBlogq);
                %    deriv = [1./A, -1./(B.^2)];
                %    pcov = pcov .* (deriv' * deriv);
                %    logxvar = pcov(1,1) + 2*pcov(1,2)*logq + pcov(2,2)*logq.^2;
                coder.internal.errorIf(logxvar < 0, ...
                    'stats:wblinv:BadCovariance');
                halfwidth = normz*sqrt(logxvar);
                % Convert back to Weibull scale
                xlo(k) = exp(logx - halfwidth);
                xup(k) = exp(logx + halfwidth);
            end
        end
    else
        x(k) = coder.internal.nan(class(x));
        if CONFINT
            xlo(k) = coder.internal.nan(class(x));
            xup(k) = coder.internal.nan(class(x));
        end
    end
end
