function dists = statguidists
%STATGUIDISTS Distribution data for RANDTOOL and DISTTOOL

% The name field is used both to display the distribution, and as an argument
% to the CDF, PDF, ICDF, and RANDOM functions.  The rvname field is used
% internally to identify a distribution given its position in this structure,
% and is also used in RANDTOOL as a workspace variable name.
%
% The pmin and pmax fields give the theoretical limits for the parameters,
% while the plo(>=pmin) and phi(<=pmax) fields give the currently enforced
% limits.

%   Copyright 1993-2011 The MathWorks, Inc.


i = 0;
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameBeta')), ...
                           'code','beta', ...
                           'rvname','betarv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameA')),getString(message('stats:statguidists:ParamNameB'))}}, ...
                           'parameters', [2 2], ...
                           'pmax', [Inf Inf], ...
                           'pmin', [0 0], ...
                           'phi', [4 4], ...
                           'plo', [0.5 0.5], ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameBinomial')), ...
                           'code','binomial', ...
                           'rvname','binorv', ...
                           'discrete', 1, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameTrials')),getString(message('stats:statguidists:ParamNameProb'))}}, ...
                           'parameters', [10 0.5],  ...
                           'pmax', [Inf 1], ...
                           'pmin', [0 0], ...
                           'phi', [10 1], ...
                           'plo', [1 0], ...
                           'intparam', [1 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameBurr')), ...
                           'code','burr', ...
                           'rvname', 'burrrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameAlpha')), ... 
                                          getString(message('stats:statguidists:ParamNameC')), ...
                                          getString(message('stats:statguidists:ParamNameK'))}}, ...
                           'parameters', [1 2.5 3], ...
                           'pmax', [Inf Inf Inf], ...
                           'pmin', [realmin realmin realmin], ...
                           'phi', [  2   5  4], ...
                           'plo', [0.5 0.7 0.7], ...
                           'intparam', [0 0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameChisquare')), ...
                           'code','chisquare', ...
                           'rvname','chi2rv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameDF'))}}, ...
                           'parameters', 2, ...
                           'pmax', Inf, ...
                           'pmin', 0, ...
                           'phi', 10, ...
                           'plo', 1, ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameDiscreteUniform')), ...
                           'code','discrete uniform', ...
                           'rvname','unidrv', ...
                           'discrete', 1, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameNumber'))}}, ...
                           'parameters', 20, ...
                           'pmax', Inf, ...
                           'pmin', 0, ...
                           'phi', 20, ...
                           'plo', 1, ...
                           'intparam', [1 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameExponential')), ...
                           'code','exponential', ...
                           'rvname','exprv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameMu'))}}, ...
                           'parameters', 1,  ...
                           'pmax', Inf, ...
                           'pmin', 0, ...
                           'phi', 2, ...
                           'plo', 0.5, ...
                           'intparam', [0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameExtremeValue')), ...
                           'code','extreme value', ...
                           'rvname','evrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameMu')),getString(message('stats:statguidists:ParamNameSigma'))}}, ...
                           'parameters', [0 1], ...
                           'pmax', [Inf Inf], ...
                           'pmin', [-Inf 0], ...
                           'phi', [5 2], ...
                           'plo', [-5 .5], ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameF')), ...
                           'code','f', ...
                           'rvname','frv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameDF1')),getString(message('stats:statguidists:ParamNameDF2'))}}, ...
                           'parameters', [5 5], ...
                           'pmax', [Inf Inf], ...
                           'pmin', [0 0], ...
                           'phi', [10 10], ...
                           'plo', [5 5], ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameGamma')), ...
                           'code','gamma', ...
                           'rvname','gamrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameA')),getString(message('stats:statguidists:ParamNameB'))}}, ...
                           'parameters', [2 2], ...
                           'pmax', [Inf Inf], ...
                           'pmin', [0 0], ...
                           'phi', [5 5], ...
                           'plo', [2 2], ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameGeneralizedExtremeValue')), ...
                           'code','generalized extreme value', ...
                           'rvname','gevrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameK')),getString(message('stats:statguidists:ParamNameSigma')),getString(message('stats:statguidists:ParamNameMu'))}}, ...
                           'parameters', [0 1 0], ...
                           'pmax', [Inf Inf Inf], ...
                           'pmin', [-Inf 0 -Inf], ...
                           'phi', [.25 2 2], ...
                           'plo', [-0.5 0.5 -2], ...
                           'intparam', [0 0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameGeneralizedPareto')), ...
                           'code','generalized pareto', ...
                           'rvname','gprv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameK')),getString(message('stats:statguidists:ParamNameSigma')),getString(message('stats:statguidists:ParamNameTheta'))}}, ...
                           'parameters', [0 1 0], ...
                           'pmax', [Inf Inf Inf], ...
                           'pmin', [-Inf 0 -Inf], ...
                           'phi', [.25 2 2], ...
                           'plo', [-0.25 0.5 -2], ...
                           'intparam', [0 0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameGeometric')), ...
                           'code','geometric', ...
                           'rvname','georv', ...
                           'discrete', 1, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameProb'))}}, ...
                           'parameters', 0.5, ...
                           'pmax', 1, ...
                           'pmin', 0, ...
                           'phi', 0.99, ...
                           'plo', 0.25, ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameHypergeometric')), ...
                           'code','hypergeometric', ...
                           'rvname','hygerv', ...
                           'discrete', 1, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameM')),getString(message('stats:statguidists:ParamNameK')),getString(message('stats:statguidists:ParamNameN'))}}, ...
                           'parameters', [8 4 3], ...
                           'pmax', [inf inf inf], ...
                           'pmin', [0 0 0], ...
                           'phi', [10 10 10], ...
                           'plo', [1 0 0], ...
                           'intparam', [1 1 1]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameLognormal')), ...
                           'code','lognormal', ...
                           'rvname','lognrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameMu')),getString(message('stats:statguidists:ParamNameSigma'))}}, ...
                           'parameters', [0.5 0.25], ...
                           'pmax', [Inf Inf], ...
                           'pmin', [-Inf 0], ...
                           'phi', [1 0.3], ...
                           'plo', [0 0.1], ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameNegativeBinomial')), ...
                           'code','negative binomial', ...
                           'rvname','nbinrv', ...
                           'discrete', 1, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameR')),getString(message('stats:statguidists:ParamNameProb'))}}, ...
                           'parameters', [2 0.6], ...
                           'pmax', [Inf 1], ...
                           'pmin', [0 0], ...
                           'phi', [3 0.99], ...
                           'plo', [1 0.5], ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameNoncentralF')), ...
                           'code','noncentral f', ...
                           'rvname','ncfrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameDF1')),getString(message('stats:statguidists:ParamNameDF2')),getString(message('stats:statguidists:ParamNameDelta'))}}, ...
                           'parameters', [5 5 1], ...
                           'pmax', [Inf Inf Inf], ...
                           'pmin', [0 0 0], ...
                           'phi', [10 10 5], ...
                           'plo', [5 5 0], ...
                           'intparam', [0 0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameNoncentralT')), ...
                           'code','noncentral t', ...
                           'rvname', 'nctrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameDF')),getString(message('stats:statguidists:ParamNamedelta'))}}, ...
                           'parameters', [5 1], ...
                           'pmax', [Inf Inf], ...
                           'pmin', [0 -Inf], ...
                           'phi', [10 5], ...
                           'plo', [2 0], ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameNoncentralChiSquare')), ...
                           'code','noncentral chi-square', ...
                           'rvname', 'ncx2rv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameDF')),getString(message('stats:statguidists:ParamNamedelta'))}}, ...
                           'parameters', [5 1], ...
                           'pmax', [Inf Inf], ...
                           'pmin', [0 0], ...
                           'phi', [10 5], ...
                           'plo', [2 0], ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameNormal')), ...
                           'code','normal', ...
                           'rvname', 'normrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameMu')),getString(message('stats:statguidists:ParamNameSigma'))}}, ...
                           'parameters', [0 1], ...
                           'pmax', [Inf Inf], ...
                           'pmin', [-Inf 0], ...
                           'phi', [2 2], ...
                           'plo', [-2 0.5], ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NamePoisson')), ...
                           'code','poisson', ...
                           'rvname', 'poissrv', ...
                           'discrete', 1, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameLambda'))}}, ...
                           'parameters', 5, ...
                           'pmax', Inf, ...
                           'pmin', 0, ...
                           'phi', 5, ...
                           'plo', 1, ...
                           'intparam', [0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameRayleigh')), ...
                           'code','rayleigh', ...
                           'rvname', 'raylrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameB'))}}, ...
                           'parameters', 2, ...
                           'pmax', Inf, ...
                           'pmin', 0, ...
                           'phi', 5, ...
                           'plo', 1, ...
                           'intparam', [0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameT')), ...
                           'code','t', ...
                           'rvname', 'trv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameDF'))}}, ...
                           'parameters', 5, ...
                           'pmax', Inf, ...
                           'pmin', 0, ...
                           'phi', 10, ...
                           'plo', 2, ...
                           'intparam', [0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameUniform')), ...
                           'code','uniform', ...
                           'rvname', 'unifrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameMin')),getString(message('stats:statguidists:ParamNameMax'))}}, ...
                           'parameters', [0 1], ...
                           'pmax', [Inf Inf], ...
                           'pmin', [-Inf -Inf], ...
                           'phi', [0.5 2], ...
                           'plo', [0 1], ...
                           'intparam', [0 0]);
i = i+1; dists(i) = struct('name',getString(message('stats:statguidists:NameWeibull')), ...
                           'code','weibull', ...
                           'rvname', 'weibrv', ...
                           'discrete', 0, ...
                           'paramnames',{{getString(message('stats:statguidists:ParamNameA')),getString(message('stats:statguidists:ParamNameB'))}}, ...
                           'parameters', [1 2], ...
                           'pmax', [Inf Inf], ...
                           'pmin', [0 0], ...
                           'phi', [3 3], ...
                           'plo', [.5 .5], ...
                           'intparam', [0 0]);
